Examples
=========

Simple
-----------------------------
Easy to use function to run all the process at once

.. literalinclude:: simple_emva_process.py

Camera simulator
----------------
Use the camera simulator to capture images

.. literalinclude:: grab.py

Report
--------
Generate a report

.. literalinclude:: sample_report.py

Module by module
----------------
EMVA1288 process calling all the modules

.. literalinclude:: full_emva_process.py

Full capture simulation
-------------------------
Simulate the capture as it would be done in the lab.

.. literalinclude:: grab_and_process.py

Custom plot
------------
Add custom image to the generated plots

.. literalinclude:: extend_plots.py

Results exchange file generation
--------------------------------
Create a results xml file for comparison

.. literalinclude:: emva_xml_create.py

Results comparison
---------------------
Compare two result files

.. literalinclude:: emva_xml_compare.py

Structure of the image data
----------------------------
:download:`Image data <EMVA1288_image_data.txt>`.


ipython